@@ -106,7 +106,8 @@ class FeatureSchema:
         self.latlng_encoder = self._create_latlng_encoder(features)
         self.eta_encoder = self._create_eta_encoder(features)
         self.eda_encoder = self._create_eda_encoder(features)
-        self.straight_dist_encoder = self._create_straight_dist_encoder(features)
+        self.straight_dist_encoder = self._create_straight_dist_encoder(
+            features)
 
     def gen_trip_vector(self, raw: RawInput) -> FeatureVector:
         return FeatureVector(
@@ -114,11 +115,14 @@ class FeatureSchema:
             pickup_lng_trunc=self.latlng_encoder.truncate(raw.pickup_lng),
             dropoff_lat_trunc=self.latlng_encoder.truncate(raw.dropoff_lat),
             dropoff_lng_trunc=self.latlng_encoder.truncate(raw.dropoff_lng),
-            start_hour_class=self.start_time_encoder.hour_class(raw.start_time),
-            start_weekday_class=self.start_time_encoder.weekday_class(raw.start_time),
+            start_hour_class=self.start_time_encoder.hour_class(
+                raw.start_time),
+            start_weekday_class=self.start_time_encoder.weekday_class(
+                raw.start_time),
             eda_scaled=self.eda_encoder.scale(raw.eda),
             eta_scaled=self.eta_encoder.scale(raw.eta),
-            straight_dist_scaled=self.straight_dist_encoder.scale(raw.straight_dist)
+            straight_dist_scaled=self.straight_dist_encoder.scale(
+                raw.straight_dist)
         )
 
     def _check_version(self, schema):
@@ -126,20 +130,25 @@ class FeatureSchema:
             raise Exception("schema.version missing")
         # TODO: auto version number instead of hard-coded
         if str(schema["version"]) != "0.1":
-            raise Exception(f"schema.version mismatch, expect: 0.1, got: {schema['version']}")
+            raise Exception(
+                f"schema.version mismatch, expect: 0.1, got: {schema['version']}")
 
     def _create_start_time_encoder(self, features) -> StartTimeEncoder:
         if "start_time" not in features:
-            raise Exception("schema.features: start_time missing\n{}".format(features))
+            raise Exception(
+                "schema.features: start_time missing\n{}".format(features))
         if "hour" not in features["start_time"]:
-            raise Exception("schema.features: start_time.hour missing\n{}".format(features))
+            raise Exception(
+                "schema.features: start_time.hour missing\n{}".format(features))
         if "weekday" not in features["start_time"]:
-            raise Exception("schema.features: start_time.weekday missing\n{}".format(features))
+            raise Exception(
+                "schema.features: start_time.weekday missing\n{}".format(features))
         return StartTimeEncoder(features["start_time"]["hour"], features["start_time"]["weekday"])
 
     def _create_latlng_encoder(self, features) -> LatLngEncoder:
         if "latlng" not in features:
-            raise Exception("schema.features: latlng missing\n{}".format(features))
+            raise Exception(
+                "schema.features: latlng missing\n{}".format(features))
         return LatLngEncoder(features["latlng"])
 
     def _create_eta_encoder(self, features) -> ScaleEncoder:
@@ -149,12 +158,14 @@ class FeatureSchema:
 
     def _create_eda_encoder(self, features) -> ScaleEncoder:
         if "EDA" not in features:
-            raise Exception("schema.features: EDA missing\n{}".format(features))
+            raise Exception(
+                "schema.features: EDA missing\n{}".format(features))
         return ScaleEncoder(features["EDA"])
 
     def _create_straight_dist_encoder(self, features) -> ScaleEncoder:
         if "straight_dist" not in features:
-            raise Exception("schema.features: straight_dist missing\n{}".format(features))
+            raise Exception(
+                "schema.features: straight_dist missing\n{}".format(features))
         return ScaleEncoder(features["straight_dist"])
 
 
